@@ -15,10 +15,11 @@ import os
 
 def create_psi_mesh(adjusted_mesh: dict, legacy_mesh: dict, mesh_type: str, dir_name: str, output_file_name=None,
                     mesh_res_file_name=None, save_plot=False, show_plot=False, save_plot_path=None,
-                    plot_file_name=None):
+                    plot_file_name=None, input_mesh=None):
     """
     Create output files and call fortran "mesh" code to create a txt file with mesh points and respective resolution,
     and cell-to-cell ratio.
+    :param input_mesh: input mesh as a dict for plotting. Optional just for plotting.
     :param plot_file_name: file name to save plot.
     :param dir_name: path to output file.
     :param mesh_res_file_name: name of file with mesh points. (t,dt, ratio) essential for plotting.
@@ -52,7 +53,7 @@ def create_psi_mesh(adjusted_mesh: dict, legacy_mesh: dict, mesh_type: str, dir_
 
     if save_plot or show_plot:
         # "plot_mesh_res": this function will plot the data in mesh_res.txt
-        plot_mesh_res(adjusted_mesh=adjusted_mesh, save_plot=save_plot, show_plot=show_plot,
+        plot_mesh_res(input_mesh=input_mesh, adjusted_mesh=adjusted_mesh, save_plot=save_plot, show_plot=show_plot,
                       mesh_res_file_name=mesh_res_path, label=mesh_type, save_plot_path=save_plot_path,
                       plot_file_name=plot_file_name)
 
@@ -71,10 +72,11 @@ if __name__ == "__main__":
     # write_tmp_mas_file(mesh_type="t", tmp_mesh_dir_name=WorkDir + "/tmp_mesh_t.dat",
     #                    tmp_mas_dir_name=WorkDir + "/tmp_mas_t.dat")
     #
-    print(adjust__mesh_r_6())
-    print(legacy__mesh_r_6())
-    create_psi_mesh(adjust__mesh_r_6().json_dict(), legacy__mesh_r_6().json_dict(), 'r', WorkDir,
-                    output_file_name="tmp_mesh_r.dat", mesh_res_file_name="mesh_res_r.dat", show_plot=True)
+    # print(adjust__mesh_phi_35())
+    # print(legacy__mesh_phi_35())
+    create_psi_mesh(adjust__mesh_phi_31().json_dict(), legacy__mesh_phi_31().json_dict(), 'p', WorkDir,
+                    output_file_name="tmp_mesh_p.dat", mesh_res_file_name="mesh_res_p.dat", show_plot=True,
+                    save_plot=False, input_mesh=get_mesh_phi_31().json_dict())
 
     # create_psi_mesh(adjust__mesh_r_1().json_dict(), legacy__mesh_r_1().json_dict(), 'r', WorkDir,
     #                     output_file_name="tmp_mesh_r.dat", mesh_res_file_name="mesh_res_r.dat",
